Tab

Enum Tab 

pub enum Tab {
    Layout,
    Segments,
    Query,
}
The currently active tab in the TUI browser.

Variants



Layout

The layout tree browser tab.

Shows the hierarchical structure of layouts in the Vortex file and allows navigation through the layout tree.



Segments

The segment map tab.

Displays a visual representation of how segments are laid out in the file.



Query

SQL query interface powered by DataFusion.