pub async fn execute_vortex_query(
session: &VortexSession,
file_path: &str,
sql: &str,
) -> Result<Vec<RecordBatch>, String>Expand description
Execute a SQL query against a Vortex file.
The file is registered as a table named “data”. Returns the result as a vector of RecordBatches.
Errors
Returns an error if the query fails to parse or execute.