pub async fn exec_inspect(
session: &VortexSession,
args: InspectArgs,
) -> Result<()>Expand description
Inspect Vortex file footer and metadata.
Errors
Returns an error if the file cannot be opened or its metadata cannot be read.
pub async fn exec_inspect(
session: &VortexSession,
args: InspectArgs,
) -> Result<()>Inspect Vortex file footer and metadata.
Returns an error if the file cannot be opened or its metadata cannot be read.