pub async fn exec_query(
session: &VortexSession,
args: QueryArgs,
) -> VortexResult<()>Expand description
Execute a SQL query against a Vortex file.
Errors
Returns an error if the file cannot be opened or the query fails.
pub async fn exec_query(
session: &VortexSession,
args: QueryArgs,
) -> VortexResult<()>Execute a SQL query against a Vortex file.
Returns an error if the file cannot be opened or the query fails.