pub fn collect_segment_tree(
root_layout: &dyn Layout,
segments: &Arc<[SegmentSpec]>,
) -> SegmentTreeExpand description
Collect segment tree from a layout and segment map.
pub fn collect_segment_tree(
root_layout: &dyn Layout,
segments: &Arc<[SegmentSpec]>,
) -> SegmentTreeCollect segment tree from a layout and segment map.