pub async fn exec_segments(
session: &VortexSession,
args: SegmentsArgs,
) -> VortexResult<()>Expand description
Display segment information for a Vortex file.
Errors
Returns an error if the file cannot be opened or read.
pub async fn exec_segments(
session: &VortexSession,
args: SegmentsArgs,
) -> VortexResult<()>Display segment information for a Vortex file.
Returns an error if the file cannot be opened or read.