pub async fn exec_tree(
session: &VortexSession,
args: TreeArgs,
) -> VortexResult<()>Expand description
Print tree views of a Vortex file (layout tree or array tree).
Errors
Returns an error if the file cannot be opened or read.
pub async fn exec_tree(
session: &VortexSession,
args: TreeArgs,
) -> VortexResult<()>Print tree views of a Vortex file (layout tree or array tree).
Returns an error if the file cannot be opened or read.