pub async fn exec_convert(
session: &VortexSession,
flags: ConvertArgs,
) -> Result<()>Expand description
Convert Parquet files to Vortex.
Errors
Returns an error if the input file cannot be read or the output file cannot be written.
pub async fn exec_convert(
session: &VortexSession,
flags: ConvertArgs,
) -> Result<()>Convert Parquet files to Vortex.
Returns an error if the input file cannot be read or the output file cannot be written.